@@ -38,10 +38,11 @@ def MATCH_AEC(refFile=None, testFile=None, caliFile=None,outFile=None,targetType
 
 
 if __name__ == '__main__':
-    ref = r'C:\Users\vcloud_avl\Downloads\Speech\TestCase_01_None_None\near_cn\far_cn.wav'
-    test = r'C:\Users\vcloud_avl\Downloads\Speech\TestCase_01_None_None\near_cn\mixDstFile.wav'
-    cali = r'C:\Users\vcloud_avl\Downloads\Speech\TestCase_01_None_None\near_cn\mixDstFile.wav'
+    path = r'D:\AudioPublicWork\3a_auto_test_porject\3a_auto_test_porject\08_TestDstFiles\sdk_zego_vivo_y3hf_music_V_shengbo_compare\aec\Speech\TestCase_01_None_None\near_cn'
+    ref = path +'\\' +'far_cn.wav'
+    test = path +'\\' + 'mixDstFile.wav'
+    cali = path +'\\' + 'mixDstFile.wav'
     outFile = r'C:\Users\vcloud_avl\Downloads\Speech\TestCase_01_None_None\near_cn\target.wav'
-    delay = MATCH_AEC(refFile=ref,testFile=test,caliFile=None,outFile=outFile,targetType=0)
+    delay = MATCH_AEC(refFile=ref,testFile=test,caliFile=cali,outFile=outFile,targetType=0)
     print(delay)
     pass
\ No newline at end of file
