@@ -35,7 +35,11 @@ def get_rms(records):
     Returns
     -------
     '''
-    return math.sqrt(sum([x * x for x in records])/len(records))
+    #return math.sqrt(sum([x * x for x in records])/len(records))
+    data = records.astype(np.float32).tolist()
+    rms = math.sqrt(sum([(x/32767) * (x/32767) for x in data])/len(data))
+    dBrmsValue = 20*math.log10(rms + 1.0E-6)
+    return dBrmsValue
 
 def isSlience(Filename =None):
     """
@@ -50,21 +54,23 @@ def isSlience(Filename =None):
     suffix = os.path.splitext(Filename)[-1]
     if suffix == '.mp4':
         Filename = get_wav_from_mp4(Filename)
-        ins, _ = get_data_array(Filename)
+        ins, _,_ = get_data_array(Filename)
     if suffix == '.pcm':
         pcmf = open(Filename, 'rb')
-        ins = pcmf.read()
+        pcmdata = pcmf.read()
+        ins = np.frombuffer(pcmdata, dtype=np.int16)
         pcmf.close()
     if suffix == '.wav':
-        ins,_ = get_data_array(Filename)
-    dBrmsValue = 20*math.log10(get_rms(ins)/32767+ 1.0E-6)
+        ins,_,_ = get_data_array(Filename)
+    dBrmsValue = get_rms(ins)#20*math.log10(get_rms(ins)/32767+ 1.0E-6)
     print(dBrmsValue)
     if dBrmsValue > -70:
         return False
     else:
         for n in range(len(ins)//480):
             curdata = ins[480*n:480*(n+1)]
-            dBrmsValue = 20 * math.log10(get_rms(curdata) / 32767 + 1.0E-6)
+            dBrmsValue = get_rms(curdata)#20 * math.log10(get_rms(curdata) / 32767 + 1.0E-6)
+            print(dBrmsValue)
             if dBrmsValue > -60:
                 return False
         return True
@@ -90,7 +96,10 @@ def audioFormat(wavFileName=None):
     refChannel,refsamWidth,refsamplerate,refframeCount = wavf.getnchannels(),wavf.getsampwidth(),wavf.getframerate(),wavf.getnframes()
     return refChannel,refsamWidth*8,refsamplerate,refframeCount
 
+
+
+
 if __name__ == '__main__':
-    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\1meiy.mp4'
+    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.pcm'
     print(isSlience(ref))
     #print(audioFormat(ref))
\ No newline at end of file
